@@ -1,17 +1,32 @@
 rel.sys <-
-function (x, type = c("matlist", "listmat"), bonds = c("entire", 
+function (x, type = c("tolist", "toarray"), bonds = c("entire", 
     "strong", "weak", "asym", "recp", "txch", "tent", "mixd", 
-    "full"), sel = NULL, prsep = ", ", loops = FALSE, att = NULL) 
+    "full"), sel = NULL, loops = FALSE, att = NULL, prsep) 
 {
+    ifelse(missing(prsep) == TRUE, prsep <- ", ", NA)
+    ifelse(missing(bonds) == TRUE, bonds <- "entire", NA)
     if (isTRUE(att == 0L) == TRUE) {
         att <- NULL
     }
     else {
         NA
     }
-    if (match.arg(type) == "matlist") {
-        if (!inherits(x, "array")) 
-            stop("\"x\" should be an array.")
+    if (all(c("strong", "weak") %in% bonds) == TRUE | isTRUE("entire" %in% 
+        bonds) == TRUE) {
+        bnds <- "entire"
+    }
+    else if (isTRUE(any(c("entire", "weak", "strong") %in% bonds)) == 
+        FALSE | isTRUE(length(bonds) > 1) == TRUE) {
+        bnds <- "Mixed"
+    }
+    else {
+        bnds <- bonds
+    }
+    if (match.arg(type) == "tolist") {
+        if (is.array(x) == FALSE) 
+            stop("'x' must be an array.")
+        if (isTRUE(dim(x)[1] == dim(x)[2]) == FALSE) 
+            stop("'x' must be a square array.")
         if (is.null(att) == FALSE) {
             if (is.na(dim(x)[3]) == FALSE) {
                 if (isTRUE(max(att) > dim(x)[3]) == TRUE) 
@@ -41,11 +56,25 @@ function (x, type = c("matlist", "listmat"), bonds = c("entire",
             bd <- bundles(x, collapse = FALSE, loops = loops, 
                 prsep = prsep)
         }
-        switch(match.arg(bonds), entire = lbd <- bd, strong = lbd <- list(bd$recp, 
-            bd$txch, bd$mixd, bd$full), weak = lbd <- list(bd$asym, 
-            bd$tent), asym = lbd <- list(bd$asym), recp = lbd <- list(bd$recp), 
-            txch = lbd <- list(bd$txch), tent = lbd <- list(bd$tent), 
-            mixd = lbd <- list(bd$mixd), full = lbd <- list(bd$full))
+        if ((bnds) == "entire") {
+            lbd <- bd
+        }
+        else if ((bnds) == "strong") {
+            lbd <- list(bd$recp, bd$txch, bd$mixd, bd$full)
+        }
+        else if ((bnds) == "weak") {
+            lbd <- list(bd$asym, bd$tent)
+        }
+        else if ((bnds) == "Mixed") {
+            ifelse(isTRUE("weak" %in% bonds) == TRUE, bonds <- unique(c(bonds, 
+                c("asym", "tent"))), NA)
+            ifelse(isTRUE("strong" %in% bonds) == TRUE, bonds <- unique(c(bonds, 
+                c("txch", "mixd", "full"))), NA)
+            lbd <- bd[which(attr(bd, "names") %in% bonds)]
+        }
+        else {
+            NA
+        }
         if (is.null(lbd) == FALSE) {
             if (is.na(dim(x)[3]) == FALSE && isTRUE((dim(x)[3] - 
                 length(att)) == 0L) == FALSE) {
@@ -81,10 +110,17 @@ function (x, type = c("matlist", "listmat"), bonds = c("entire",
                   1L) == TRUE, sel <- diag(sel), sel <- diag(mnplx(sel)))
                 sel <- as.vector(attr(which(!(sel == 0)), "names"))
             }
+            if (is.null(dimnames(x)) == FALSE) {
+                ifelse(isTRUE(is.numeric(sel) == TRUE) == TRUE, 
+                  Sel <- dimnames(x)[[1]][sel], Sel <- sel)
+            }
+            else {
+                Sel <- sel
+            }
             ntsel <- list()
             length(ntsel) <- length(stb)
             for (k in 1:length(stb)) {
-                tss <- which(dhc(stb[[k]]) %in% sel)
+                tss <- which(dhc(stb[[k]]) %in% Sel)
                 if (isTRUE(length(tss) > 0) == TRUE) {
                   tmpsel <- vector()
                   for (i in 1:length(tss)) {
@@ -100,7 +136,7 @@ function (x, type = c("matlist", "listmat"), bonds = c("entire",
                 }
             }
             rm(k)
-            rm(tmpsel, tss)
+            rm(tss)
             stb <- ntsel
         }
         else {
@@ -174,30 +210,52 @@ function (x, type = c("matlist", "listmat"), bonds = c("entire",
         class(RS) <- "Rel.System"
         return(RS)
     }
-    else if (match.arg(type) == "listmat") {
-        if (isTRUE(attr(x, "class") == "Rel.System") == FALSE) 
-            stop("Relational system must be a \"Rel.System\" class.")
+    else if (match.arg(type) == "toarray") {
+        if (isTRUE(attr(x, "class") == "Rel.System") == FALSE) {
+            if (is.null(sel) == TRUE) {
+                x <- rel.sys(x, type = "tolist", bonds = bonds, 
+                  loops = loops, att = att)
+            }
+            else {
+                if (is.array(sel) == TRUE) {
+                  ifelse(is.na(dim(sel)[3]) == TRUE | isTRUE(dim(sel)[3] == 
+                    1L) == TRUE, sel <- diag(sel), sel <- diag(mnplx(sel)))
+                  sel <- as.vector(attr(which(!(sel == 0)), "names"))
+                }
+                else {
+                  NA
+                }
+                ifelse(isTRUE(is.numeric(sel) == TRUE) == TRUE, 
+                  Sel <- dimnames(x)[[1]][sel], Sel <- sel)
+                ifelse(isTRUE(Sel == "att") == TRUE | isTRUE(Sel == 
+                  "noatt") == TRUE, x <- rel.sys(x, type = "tolist", 
+                  bonds = bonds, loops = loops, att = att), x <- rel.sys(x, 
+                  type = "tolist", bonds = bonds, sel = Sel, 
+                  loops = loops, att = att))
+            }
+        }
+        else {
+            NA
+        }
         if (isTRUE(x$sys.ord == 0L) == TRUE) 
             stop("Relational system chosen is empty!")
-        if (isTRUE(bonds != "entire") == TRUE) 
-            warning("'bonds' is only for the \"matlist\" option.")
-        lbst <- attr(x$Ties, "names")
         if (is.null(sel) == FALSE) {
-            if (isTRUE(sel == 1L) == TRUE) {
-                sel <- x$nodes[which(x$nodes %in% unlist(dhc(x$Attrs)))]
+            if (isTRUE(sel == "att") == TRUE) {
+                Sel <- x$nodes[which(x$nodes %in% unlist(dhc(x$Attrs)))]
             }
-            else if (isTRUE(sel == 0L) == TRUE) {
-                sel <- x$nodes[which(!(x$nodes %in% unlist(dhc(x$Attrs))))]
+            else if (isTRUE(sel == "noatt") == TRUE) {
+                Sel <- x$nodes[which(!(x$nodes %in% unlist(dhc(x$Attrs))))]
             }
-            else if (isTRUE(any(sel %in% x$nodes)) == FALSE) {
+            else if (isTRUE(any(Sel %in% x$nodes)) == FALSE) {
                 return(sel)
             }
             else {
                 NA
             }
+            lbst <- vector()
             ntsel <- list()
             for (k in 1:length(x$Ties)) {
-                tss <- which(dhc(x$Ties[[k]]) %in% sel)
+                tss <- which(dhc(x$Ties[[k]]) %in% Sel)
                 if (isTRUE(length(tss) > 0) == TRUE) {
                   tmpsel <- vector()
                   for (i in 1:length(tss)) {
@@ -210,14 +268,16 @@ function (x, type = c("matlist", "listmat"), bonds = c("entire",
                   }
                   rm(i)
                   ntsel[[k]] <- as.vector(unlist(tmpsel))
+                  lbst <- append(lbst, attr(x$Ties, "names")[k])
                 }
                 else {
-                  lbst <- lbst[which(!(lbst %in% lbst[k]))]
+                  NA
                 }
             }
             rm(k)
             rm(tss)
             ntsel <- ntsel[unlist(lapply(ntsel, length) != 0)]
+            attr(ntsel, "names") <- lbst
             x$Ties <- ntsel
             lbs <- unique(dhc(unlist(ntsel)))
             n <- length(lbs)
@@ -227,22 +287,23 @@ function (x, type = c("matlist", "listmat"), bonds = c("entire",
             n <- x$sys.ord
             r <- length(x$Ties)
             lbs <- x$incl
+            lbst <- attr(x$Ties, "names")
         }
         arr <- array(0, dim = c(n, n, r))
+        dimnames(arr)[[1]] <- dimnames(arr)[[2]] <- lbs
+        if (isTRUE(n > 0) == TRUE) 
+            dimnames(arr)[[3]] <- lbst
         for (i in 1:r) {
             if (isTRUE(length(x$Ties[[i]]) > 0) == TRUE && isTRUE(n > 
                 0) == TRUE) {
-                arr[, , i] <- transf(x$Ties[[i]], type = "listmat", 
-                  ord = n, labels = lbs)
+                arr[, , i] <- transf(x$Ties[[i]], type = "toarray", 
+                  ord = n, labels = lbs, lb2lb = TRUE)
             }
             else {
                 NA
             }
         }
         rm(i)
-        dimnames(arr)[[1]] <- dimnames(arr)[[2]] <- lbs
-        if (isTRUE(n > 0) == TRUE) 
-            dimnames(arr)[[3]] <- lbst
         if (is.null(x$Attrs) == FALSE) {
             arra <- array(0, dim = c(n, n, length(x$Attrs)))
             dimnames(arra)[[1]] <- dimnames(arra)[[2]] <- lbs
